@@ -13,7 +13,7 @@ async function requestAPI<T>(path = '', init: RequestInit = {}): Promise<T> {
   // Make request to Jupyter API
   const settings = ServerConnection.makeSettings();
   const requestUrl = URLExt.join(settings.baseUrl, path);
-  console.log('handler.ts:requestAPI:requestUrl: ', requestUrl);
+  console.debug('handler.ts:requestAPI:requestUrl: ', requestUrl);
 
   let response: Response;
   try {
@@ -24,7 +24,7 @@ async function requestAPI<T>(path = '', init: RequestInit = {}): Promise<T> {
   }
 
   const data = await response.json();
-  console.log('handler.ts:requestAPI:data: ', data);
+  console.debug('handler.ts:requestAPI:data: ', data);
 
   if (!response.ok) {
     throw new ServerConnection.ResponseError(response, data.message);
